@@ -4,8 +4,10 @@
  *  License: MIT (See the LICENSE file in the repository root directory)
  */
 
-use cli::SetUp;
-use structopt::StructOpt;
+use crate::cli::opt::Opt;
+use cli::structures::{
+    CheckCommand, CmpCommand, ExampleCommand, RunCommand, SetupCommand, TLECommand,
+};
 
 pub mod cli;
 pub mod config;
@@ -14,18 +16,16 @@ pub mod diff;
 pub mod error;
 pub mod file_handler;
 pub mod generator;
+pub mod language;
 pub mod painter;
 pub mod runner;
 pub mod subcommand;
 pub mod util;
 
-use crate::cli::Opt;
-
 use exitfailure::ExitFailure;
+use structopt::StructOpt;
 
 fn main() -> Result<(), ExitFailure> {
-    config::scheme::load_default_config();
-
     let opt = Opt::from_args();
 
     #[cfg(windows)]
@@ -45,7 +45,7 @@ fn main() -> Result<(), ExitFailure> {
             run_wa,
             run_tle,
             run_rte,
-        } => subcommand::cmd_tle::run(
+        } => subcommand::cmd_tle::run(&TLECommand::new(
             target_file,
             gen_file,
             test_cases,
@@ -58,7 +58,7 @@ fn main() -> Result<(), ExitFailure> {
             run_wa,
             run_tle,
             run_rte,
-        ),
+        )),
         Opt::Cmp {
             target_file,
             correct_file,
@@ -74,7 +74,7 @@ fn main() -> Result<(), ExitFailure> {
             run_tle,
             run_rte,
             diff,
-        } => subcommand::cmd_cmp::run(
+        } => subcommand::cmd_cmp::run(&CmpCommand::new(
             target_file,
             correct_file,
             gen_file,
@@ -89,7 +89,7 @@ fn main() -> Result<(), ExitFailure> {
             run_tle,
             run_rte,
             diff,
-        ),
+        )),
         Opt::Check {
             target_file,
             checker_file,
@@ -104,7 +104,7 @@ fn main() -> Result<(), ExitFailure> {
             run_wa,
             run_tle,
             run_rte,
-        } => subcommand::cmd_check::run(
+        } => subcommand::cmd_check::run(&CheckCommand::new(
             target_file,
             checker_file,
             gen_file,
@@ -118,24 +118,27 @@ fn main() -> Result<(), ExitFailure> {
             run_wa,
             run_tle,
             run_rte,
-        ),
+        )),
         Opt::Run {
             target_file,
             prefix,
             timeout,
             break_bad,
             save_out,
-        } => subcommand::cmd_run::run(target_file, &prefix[..], timeout, break_bad, save_out),
+        } => subcommand::cmd_run::run(&RunCommand::new(
+            target_file,
+            prefix,
+            timeout,
+            break_bad,
+            save_out,
+        )),
         Opt::Setup { subcommand } => match subcommand {
-            SetUp::Cpp {
-                program,
-                standard,
-                flags,
-            } => subcommand::cmd_setup::setup_cpp(&program[..], &standard[..], &flags[..]),
-            SetUp::Python { program, flags } => {
-                subcommand::cmd_setup::setup_python(&program[..], &flags[..])
+            cli::opt::SetUp::Config { label, value } => {
+                subcommand::cmd_setup::run(&SetupCommand::new(label, value))
             }
         },
-        Opt::Example { cmp, tle, check } => subcommand::cmd_example::run(cmp, tle, check),
+        Opt::Example { cmp, tle, check } => {
+            subcommand::cmd_example::run(&ExampleCommand::new(cmp, tle, check))
+        }
     }
 }
