@@ -96,6 +96,16 @@ pub fn show_runtime_error(test_number: u32, time: u32) {
     );
 }
 
+pub fn show_ran_successfully(test_number: u32, time: u32) {
+    println!(
+        "  {} [{}] {} {}ms",
+        test_number.to_string().bold().white(),
+        "OK".bold().green(),
+        "Ran Successfully".bold().green(),
+        time
+    );
+}
+
 pub fn show_stats(ac: u32, wa: u32, tle: u32, rte: u32) {
     #[cfg(unix)]
     println!("\n  📌{}\n", "-Stats-".bold().white());
