@@ -9,6 +9,7 @@ use std::collections::VecDeque;
 use std::path::PathBuf;
 use std::time::Duration;
 
+use crate::cli::structures::CheckCommand;
 // local library
 use crate::error::handle_error::{
     throw_break_found_msg, throw_compiler_error_msg, throw_runtime_error_msg,
@@ -21,6 +22,7 @@ use crate::file_handler::file::{
 };
 use crate::file_handler::path::get_root_path;
 use crate::generator::generator::execute_generator;
+use crate::language::language_handler::{get_generator_handler, get_language_handler};
 use crate::painter::style::{
     show_accepted, show_runtime_error, show_stats, show_time_limit_exceeded,
     show_time_limit_exceeded_checker, show_wrong_answer,
@@ -36,85 +38,80 @@ use crate::constants::{
     PREFIX_TLE_FILES, PREFIX_WA_FILES, QTEST_CHECKER_FILE, QTEST_ERROR_FILE, QTEST_INPUT_FILE,
     QTEST_OUTPUT_FILE, TARGET_BINARY_FILE, TEST_CASES_FOLDER,
 };
-use crate::util::lang::{get_language_by_ext_default, get_language_by_ext_set_output};
 
 #[allow(clippy::too_many_arguments)]
-pub fn run(
-    target_file: PathBuf,
-    checker_file: PathBuf,
-    gen_file: PathBuf,
-    timeout: u32,
-    test_cases: u32,
-    break_bad: bool,
-    save_bad: bool,
-    save_all: bool,
-    run_all: bool,
-    run_ac: bool,
-    run_wa: bool,
-    run_tle: bool,
-    run_rte: bool,
-) -> Result<(), ExitFailure> {
+pub fn run(command: &CheckCommand) -> Result<(), ExitFailure> {
     // create cache folder
     create_folder_or_error(CACHE_FOLDER)?;
 
     // verify that the target file exists
-    file_exists_or_error(target_file.to_str().unwrap(), "<target-file>")?;
+    file_exists_or_error(command.target_file.to_str().unwrap(), "<target-file>")?;
 
     // verify that the checker_file file exists
-    file_exists_or_error(checker_file.to_str().unwrap(), "<checker-file>")?;
+    file_exists_or_error(command.checker_file.to_str().unwrap(), "<checker-file>")?;
 
     // verify that the generator file exists
-    file_exists_or_error(gen_file.to_str().unwrap(), "<gen-file>")?;
+    file_exists_or_error(command.gen_file.to_str().unwrap(), "<gen-file>")?;
 
     // verify that the target file extension is supported
-    is_extension_supported_or_error(target_file.to_str().unwrap())?;
+    is_extension_supported_or_error(command.target_file.to_str().unwrap())?;
 
     // verify that the checker file extension is supported
-    is_extension_supported_or_error(checker_file.to_str().unwrap())?;
+    is_extension_supported_or_error(command.checker_file.to_str().unwrap())?;
 
     // verify that the generator file extension is supported
-    is_extension_supported_or_error(gen_file.to_str().unwrap())?;
+    is_extension_supported_or_error(command.gen_file.to_str().unwrap())?;
 
     let root = &get_root_path()[..];
 
     // Get the language depending on the extension of the gen_file
-    let any_gen: Option<Box<dyn Language>> =
-        get_language_by_ext_set_output(root, gen_file, GEN_BINARY_FILE, QTEST_INPUT_FILE);
-    let any_gen: Box<dyn Language> = any_gen.unwrap();
-    let generator_file_lang: &dyn Language = any_gen.as_ref();
+    let generator_file_lang = *get_generator_handler(
+        &command
+            .gen_file
+            .clone()
+            .into_os_string()
+            .into_string()
+            .unwrap()[..],
+        "<gen-file>",
+        QTEST_INPUT_FILE,
+    )?;
 
     // verify that the program to run the generator file is installed
-    can_run_language_or_error(generator_file_lang)?;
+    can_run_language_or_error(&generator_file_lang)?;
 
     // Get the language depending on the extension of the target_file
-    let any_target: Option<Box<dyn Language>> = get_language_by_ext_default(
-        root,
-        target_file,
-        TARGET_BINARY_FILE,
+    let target_file_lang = *get_language_handler(
+        &command
+            .target_file
+            .clone()
+            .into_os_string()
+            .into_string()
+            .unwrap()[..],
+        "<target-file>",
         QTEST_INPUT_FILE,
         QTEST_OUTPUT_FILE,
         QTEST_ERROR_FILE,
-    );
-    let any_target: Box<dyn Language> = any_target.unwrap();
-    let target_file_lang: &dyn Language = any_target.as_ref();
+    )?;
 
     // verify that the program to run the target file is installed
-    can_run_language_or_error(target_file_lang)?;
+    can_run_language_or_error(&target_file_lang)?;
 
     // Get the language depending on the extension of the checker_file_lang
-    let any_checker: Option<Box<dyn Language>> = get_language_by_ext_default(
-        root,
-        checker_file,
-        CHECKER_BINARY_FILE,
+    let checker_file_lang_lang = *get_language_handler(
+        &command
+            .checker_file
+            .clone()
+            .into_os_string()
+            .into_string()
+            .unwrap()[..],
+        "<checker-file>",
         QTEST_OUTPUT_FILE,
         QTEST_CHECKER_FILE,
         QTEST_ERROR_FILE,
-    );
-    let any_checker: Box<dyn Language> = any_checker.unwrap();
-    let checker_file_lang_lang: &dyn Language = any_checker.as_ref();
+    )?;
 
     // verify that the program to run the checker file is installed
-    can_run_language_or_error(checker_file_lang_lang)?;
+    can_run_language_or_error(&checker_file_lang_lang)?;
 
     let can_compile_gen = generator_file_lang.build();
     if !can_compile_gen {
@@ -131,7 +128,7 @@ pub fn run(
         return throw_compiler_error_msg("checker", "<checker-file>");
     }
 
-    if save_bad || save_all {
+    if command.save_bad || command.save_all {
         // Remove all previous test cases
         remove_folder(TEST_CASES_FOLDER);
     }
@@ -140,11 +137,11 @@ pub fn run(
     load_testcases_from_states(
         &mut cases,
         TEST_CASES_FOLDER,
-        run_all,
-        run_ac,
-        run_wa,
-        run_tle,
-        run_rte,
+        command.run_all,
+        command.run_ac,
+        command.run_wa,
+        command.run_tle,
+        command.run_rte,
     )?;
 
     let mut tle_count: u32 = 0;
@@ -152,11 +149,12 @@ pub fn run(
     let mut rte_count: u32 = 0;
     let mut ac_count: u32 = 0;
 
-    let load_case: bool = run_all || run_ac || run_wa || run_tle || run_rte;
+    let load_case: bool =
+        command.run_all || command.run_ac || command.run_wa || command.run_tle || command.run_rte;
 
     let mut test_number: u32 = 0;
 
-    while test_number < test_cases || load_case {
+    while test_number < command.test_cases || load_case {
         test_number += 1;
 
         if load_case {
@@ -169,25 +167,25 @@ pub fn run(
             }
         } else {
             // run generator
-            execute_generator(generator_file_lang, timeout, test_number)?;
+            execute_generator(&generator_file_lang, command.timeout, test_number)?;
         }
 
-        let response_target = target_file_lang.execute(timeout as u32, test_number);
+        let response_target = target_file_lang.execute(command.timeout as u32, test_number);
         let time_target: Duration = response_target.time;
         let mills_target: u128 = time_target.as_millis();
 
         if is_runtime_error(&response_target.status) {
             rte_count += 1;
             show_runtime_error(test_number, mills_target as u32);
-            if save_bad || save_all {
+            if command.save_bad || command.save_all {
                 // Example: test_cases/testcase_rte_01.txt
                 let file_name: &str =
                     &format_filename_test_case(TEST_CASES_FOLDER, PREFIX_RTE_FILES, rte_count)[..];
                 // save testcase
                 save_test_case(file_name, QTEST_INPUT_FILE);
             }
-            // check if the break_bad flag is high
-            if break_bad {
+            // check if the command.break_bad flag is high
+            if command.break_bad {
                 // remove input, output and error files
                 remove_files(vec![
                     QTEST_INPUT_FILE,
@@ -205,7 +203,7 @@ pub fn run(
             return throw_compiler_error_msg("target", "<target-file>");
         }
 
-        let response_checker = checker_file_lang_lang.execute(timeout as u32, test_number);
+        let response_checker = checker_file_lang_lang.execute(command.timeout as u32, test_number);
         let time_checker: Duration = response_checker.time;
 
         if is_runtime_error(&response_checker.status) {
@@ -214,20 +212,20 @@ pub fn run(
             return throw_compiler_error_msg("checker", "<checker-file>");
         }
 
-        if time_checker >= Duration::from_millis(timeout as u64) {
+        if time_checker >= Duration::from_millis(command.timeout as u64) {
             // TLE checker file
-            show_time_limit_exceeded_checker(test_number, timeout);
+            show_time_limit_exceeded_checker(test_number, command.timeout);
             return throw_time_limit_exceeded_msg("checker", "<checker-file>");
         }
 
-        if time_target >= Duration::from_millis(timeout as u64)
+        if time_target >= Duration::from_millis(command.timeout as u64)
             || is_time_limit_exceeded(&response_target.status)
         {
             // TLE Target file
             tle_count += 1;
-            show_time_limit_exceeded(test_number, timeout);
+            show_time_limit_exceeded(test_number, command.timeout);
 
-            if save_bad || save_all {
+            if command.save_bad || command.save_all {
                 // Example: test_cases/testcase_tle_01.txt
                 let file_name: &str =
                     &format_filename_test_case(TEST_CASES_FOLDER, PREFIX_TLE_FILES, tle_count)[..];
@@ -235,8 +233,8 @@ pub fn run(
                 save_test_case(file_name, QTEST_INPUT_FILE);
             }
 
-            // check if the break_bad flag is high
-            if break_bad {
+            // check if the command.break_bad flag is high
+            if command.break_bad {
                 // remove input, output and error files
                 remove_files(vec![
                     QTEST_INPUT_FILE,
@@ -258,7 +256,7 @@ pub fn run(
                 // is OK
                 ac_count += 1;
                 show_accepted(test_number, mills_target as u32);
-                if save_all {
+                if command.save_all {
                     // Example: test_cases/testcase_ac_01.txt
                     let file_name: &str = &format_filename_test_case(
                         TEST_CASES_FOLDER,
@@ -274,7 +272,7 @@ pub fn run(
 
                 show_wrong_answer(test_number, mills_target as u32);
 
-                if save_bad || save_all {
+                if command.save_bad || command.save_all {
                     // Example: test_cases/testcase_wa_01.txt
                     let file_name: &str = &format_filename_test_case(
                         TEST_CASES_FOLDER,
@@ -285,7 +283,7 @@ pub fn run(
                     save_test_case(file_name, QTEST_INPUT_FILE);
                 }
 
-                if break_bad {
+                if command.break_bad {
                     // remove input, output and error files
                     remove_files(vec![
                         QTEST_INPUT_FILE,
@@ -297,7 +295,7 @@ pub fn run(
                         CHECKER_BINARY_FILE,
                     ]);
 
-                    return throw_break_found_msg("Wrong Answer", "WA", test_cases);
+                    return throw_break_found_msg("Wrong Answer", "WA", command.test_cases);
                 }
             }
         }
@@ -322,48 +320,19 @@ pub fn run(
 // checker compare  compare_file
 
 pub fn check_answer(answer_file: &str, ignore_space: bool) -> bool {
-    let mut is_good = true;
-    let target_content = match std::fs::read_to_string(answer_file) {
-        Ok(content) => Some(content),
-        Err(_) => {
-            is_good = false;
-            None
-        }
-    };
+    let mut target_content_str = String::new();
 
-    if !is_good {
-        return false;
-    }
-
-    let mut target_content_vec: VecDeque<char> = VecDeque::new();
-    is_good = match target_content {
-        Some(s1) => {
-            target_content_vec = s1.to_lowercase().chars().collect::<VecDeque<char>>();
-            true
-        }
-        _ => false,
-    };
-
-    if !is_good {
+    if let Ok(s1) = std::fs::read_to_string(answer_file) {
+        target_content_str.push_str(&s1.to_lowercase());
+    } else {
         return false;
     }
 
     if ignore_space {
         // Remove spaces at the beginning and end of the file
         // for target_content_vec
-        while !target_content_vec.is_empty()
-            && (*target_content_vec.back().unwrap() == ' '
-                || *target_content_vec.back().unwrap() == '\n')
-        {
-            target_content_vec.pop_back();
-        }
-        while !target_content_vec.is_empty()
-            && (*target_content_vec.front().unwrap() == ' '
-                || *target_content_vec.front().unwrap() == '\n')
-        {
-            target_content_vec.pop_front();
-        }
+        target_content_str = target_content_str.trim().to_string();
     }
 
-    target_content_vec == vec!['y', 'e', 's']
+    "yes" == &target_content_str[..]
 }
